@@ -1,8 +1,6 @@
 package Bundle::WWW::Search;
 
-$VERSION = '1.04';
-
-1;
+$VERSION = '1.06';
 
 __END__
 
@@ -20,6 +18,7 @@ Bundle::LWP		- prerequisite
 
 File::Spec		- prerequisite
 
+HTML::Parse             - prerequisite
 HTML::Parser            - prerequisite
 HTML::TreeBuilder       - prerequisite
 
@@ -30,9 +29,16 @@ HTTP::Status            - prerequisite
 LWP::RobotUA            - prerequisite
 LWP::UserAgent          - prerequisite
 
+MIME::Line              - only needed for AutoSearch's --mail option
+
+Net::Domain             - prerequisite
+
+URI                     - prerequisite
 URI::Escape             - prerequisite
 
-WWW::Search
+User                    - prerequisite
+
+WWW::Search             - the distribution itself
 
 =head1 DESCRIPTION
 
@@ -41,7 +47,7 @@ WWW::Search, as well as the basic WWW::Search mechanism itself.
 
 =head1 AUTHOR
 
-Martin Thurn E<lt>F<martinthurn@iname.com>E<gt>
+Martin Thurn E<lt>F<mthurn@cpan.org>E<gt>
 (Author only of this bundle, not necessarily of the modules it lists)
 
 =cut
